==================================================
  AI COMMIT MESSAGE TOOL (aicommitter) INSTALLED
==================================================

Usage Steps:

STEP 1: 
export DEEPSEEK_API_KEY="sk-*"

STEP 2:
alias aicommitter="aicommit"

STEP 3:
aicommit install

STEP 4:
git add .

STEP 5:
aicommit generate --commit
